'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactRedux = require('react-redux');

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _record = require('../../actions/record');

var _reducers = require('../../reducers');

var _RecordEditor = require('../../components/record/RecordEditor');

var _RecordEditor2 = _interopRequireDefault(_RecordEditor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mapStateToProps = function mapStateToProps(state, ownProps) {
  var csid = ownProps.csid;


  return {
    data: (0, _reducers.getRecordData)(state, csid),
    isModified: (0, _reducers.isRecordModified)(state, csid),
    isSavePending: (0, _reducers.isRecordSavePending)(state, csid)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch, ownProps) {
  var config = ownProps.config,
      csid = ownProps.csid,
      relatedSubjectCsid = ownProps.relatedSubjectCsid,
      recordType = ownProps.recordType,
      vocabulary = ownProps.vocabulary;


  var recordTypeConfig = (0, _get2.default)(config, ['recordTypes', recordType]);

  var vocabularyConfig = vocabulary ? (0, _get2.default)(recordTypeConfig, ['vocabularies', vocabulary]) : undefined;

  return {
    createNewRecord: function createNewRecord(cloneCsid) {
      dispatch((0, _record.createNewRecord)(recordTypeConfig, vocabularyConfig, cloneCsid));
    },
    readRecord: function readRecord() {
      dispatch((0, _record.readRecord)(recordTypeConfig, vocabularyConfig, csid));
    },
    onAddInstance: function onAddInstance(path) {
      dispatch((0, _record.addFieldInstance)(recordTypeConfig, csid, path));
    },
    onCommit: function onCommit(path, value) {
      dispatch((0, _record.setFieldValue)(csid, path, value));
    },
    onMoveInstance: function onMoveInstance(path, newPosition) {
      dispatch((0, _record.moveFieldValue)(csid, path, newPosition));
    },
    onRemoveInstance: function onRemoveInstance(path) {
      dispatch((0, _record.deleteFieldValue)(csid, path));
    },
    revert: function revert() {
      dispatch((0, _record.revertRecord)(csid));
    },
    save: function save(onRecordCreated) {
      dispatch((0, _record.saveRecord)(recordTypeConfig, vocabularyConfig, csid, relatedSubjectCsid, onRecordCreated));
    }
  };
};

exports.default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(_RecordEditor2.default);