'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findFieldConfigInPart = exports.findField = exports.getDefaultSearchVocabulary = exports.getDefaultSearchRecordType = exports.validateLocation = exports.isAuthority = exports.isCloneable = exports.getDefaults = exports.getDefaultValue = exports.getVocabularyConfigByShortID = exports.getRecordTypeConfigByServicePath = exports.getRecordTypeNameByServiceObjectName = exports.getRecordTypeConfigByServiceObjectName = exports.normalizeConfig = exports.initConfig = exports.mergeConfig = exports.applyPlugins = exports.applyPlugin = exports.evaluatePlugin = exports.dataPathToFieldDescriptorPath = exports.configKey = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _deepAssign = require('deep-assign');

var _deepAssign2 = _interopRequireDefault(_deepAssign);

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _set = require('lodash/set');

var _set2 = _interopRequireDefault(_set);

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

var _errorCodes = require('../constants/errorCodes');

var _recordDataHelpers = require('./recordDataHelpers');

var _csidHelpers = require('./csidHelpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var onlyDigitsPattern = /^\d+$/;
var isNotNumeric = function isNotNumeric(string) {
  return !onlyDigitsPattern.test(string);
};

var configKey = exports.configKey = Symbol.for('configHelpers.configKey');

var dataPathToFieldDescriptorPath = exports.dataPathToFieldDescriptorPath = function dataPathToFieldDescriptorPath(dataPath) {
  return dataPath.filter(isNotNumeric);
};

var evaluatePlugin = exports.evaluatePlugin = function evaluatePlugin(plugin, pluginContext) {
  var pluginType = typeof plugin === 'undefined' ? 'undefined' : _typeof(plugin);

  var isValidType = plugin && (pluginType === 'function' || pluginType === 'object' && !Array.isArray(plugin));

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isValidType, 'A plugin must be an object or a function.') : void 0;

  if (!isValidType) {
    return {};
  }

  return pluginType === 'object' ? plugin : plugin(pluginContext);
};

var applyPlugin = exports.applyPlugin = function applyPlugin(targetConfig, plugin, pluginContext) {
  var pluginConfigContribution = evaluatePlugin(plugin, pluginContext);

  /* Gotta do this mutual recursion */
  /* eslint-disable no-use-before-define */
  return mergeConfig(targetConfig, pluginConfigContribution, pluginContext);
  /* eslint-enable no-use-before-define */
};

var applyPlugins = exports.applyPlugins = function applyPlugins(targetConfig, plugins, pluginContext) {
  var isArray = Array.isArray(plugins);

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isArray, 'Plugins must be an array.') : void 0;

  if (!isArray) {
    return targetConfig;
  }

  return plugins.reduce(function (updatedConfig, plugin) {
    return applyPlugin(updatedConfig, plugin, pluginContext);
  }, targetConfig);
};

var mergeConfig = exports.mergeConfig = function mergeConfig(targetConfig, sourceConfig, pluginContext) {
  var pluginsAppliedConfig = sourceConfig && 'plugins' in sourceConfig ? applyPlugins(targetConfig, sourceConfig.plugins, pluginContext) : targetConfig;

  var mergedConfig = (0, _deepAssign2.default)({}, pluginsAppliedConfig, sourceConfig);

  delete mergedConfig.plugins;

  return mergedConfig;
};

var initConfig = exports.initConfig = function initConfig(config, pluginContext) {
  return mergeConfig({}, config, pluginContext);
};

/*
 * Normalize a configuration object. This function mutates the argument configuration.
 * - Set the name property of each recordTypes entry to its key
 * - Set the name property of each vocabularies entry to its key
 */
var normalizeConfig = exports.normalizeConfig = function normalizeConfig(config) {
  var recordTypes = config.recordTypes;

  Object.keys(recordTypes).forEach(function (recordTypeName) {
    var recordType = recordTypes[recordTypeName];
    var vocabularies = recordType.vocabularies;

    recordType.name = recordTypeName;

    if (vocabularies) {
      Object.keys(vocabularies).forEach(function (vocabularyName) {
        vocabularies[vocabularyName].name = vocabularyName;
      });
    }
  });

  return config;
};

var getRecordTypeConfigByServiceObjectName = exports.getRecordTypeConfigByServiceObjectName = function getRecordTypeConfigByServiceObjectName(config, objectName) {
  if (!objectName) {
    return undefined;
  }

  if (!config.recordTypesByServiceObjectName) {
    var recordTypesByServiceObjectName = {};
    var recordTypes = config.recordTypes;


    Object.keys(recordTypes).forEach(function (recordType) {
      var recordTypeConfig = recordTypes[recordType];

      recordTypesByServiceObjectName[recordTypeConfig.serviceConfig.objectName] = recordTypeConfig;
    });

    /* eslint-disable no-param-reassign */
    config.recordTypesByServiceObjectName = recordTypesByServiceObjectName;
    /* eslint-enable no-param-reassign */
  }

  return config.recordTypesByServiceObjectName[objectName];
};

var getRecordTypeNameByServiceObjectName = exports.getRecordTypeNameByServiceObjectName = function getRecordTypeNameByServiceObjectName(config, objectName) {
  var recordTypeConfig = getRecordTypeConfigByServiceObjectName(config, objectName);

  return recordTypeConfig ? recordTypeConfig.name : undefined;
};

var getRecordTypeConfigByServicePath = exports.getRecordTypeConfigByServicePath = function getRecordTypeConfigByServicePath(config, servicePath) {
  if (!config.recordTypesByServicePath) {
    var recordTypesByServicePath = {};
    var recordTypes = config.recordTypes;


    Object.keys(recordTypes).forEach(function (recordType) {
      var recordTypeConfig = recordTypes[recordType];

      recordTypesByServicePath[recordTypeConfig.serviceConfig.servicePath] = recordTypeConfig;
    });

    /* eslint-disable no-param-reassign */
    config.recordTypesByServicePath = recordTypesByServicePath;
    /* eslint-enable no-param-reassign */
  }

  return config.recordTypesByServicePath[servicePath];
};

var getVocabularyConfigByShortID = exports.getVocabularyConfigByShortID = function getVocabularyConfigByShortID(recordTypeConfig, shortID) {
  if (!recordTypeConfig.vocabulariesByShortID) {
    var vocabulariesByShortID = {};
    var vocabularies = recordTypeConfig.vocabularies;


    if (vocabularies) {
      Object.keys(vocabularies).forEach(function (vocabulary) {
        var vocabularyConfig = vocabularies[vocabulary];
        var servicePath = vocabularyConfig.serviceConfig.servicePath;


        if (servicePath && servicePath.indexOf('urn:cspace:name(') === 0 && servicePath.lastIndexOf(')') === servicePath.length - 1) {
          var vocabularyShortID = servicePath.substring(16, servicePath.length - 1);

          vocabulariesByShortID[vocabularyShortID] = vocabularyConfig;
        }
      });

      /* eslint-disable no-param-reassign */
      recordTypeConfig.vocabulariesByShortID = vocabulariesByShortID;
      /* eslint-enable no-param-reassign */
    }
  }

  return recordTypeConfig.vocabulariesByShortID[shortID];
};

var getDefaultValue = exports.getDefaultValue = function getDefaultValue(fieldDescriptor) {
  var config = fieldDescriptor[configKey];

  if (config) {
    var defaultValue = config.defaultValue;


    if ((typeof defaultValue === 'undefined' ? 'undefined' : _typeof(defaultValue)) === 'object' && !_immutable2.default.Map.isMap(defaultValue)) {
      // If an object is supplied as a default value, convert it to an immutable map.

      return _immutable2.default.fromJS(defaultValue);
    }

    return defaultValue;
  }

  return undefined;
};

var getDefaults = exports.getDefaults = function getDefaults(fieldDescriptor) {
  var currentPath = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  var results = [];

  var defaultValue = getDefaultValue(fieldDescriptor);

  if (typeof defaultValue !== 'undefined') {
    results = results.concat({
      path: currentPath,
      value: defaultValue
    });
  }

  var childKeys = Object.keys(fieldDescriptor).filter(function (key) {
    return key !== configKey;
  });

  childKeys.forEach(function (childKey) {
    var childPath = currentPath.concat(childKey);
    var childfieldDescriptor = fieldDescriptor[childKey];
    var childResults = getDefaults(childfieldDescriptor, childPath);

    results = results.concat(childResults);
  });

  return results;
};

var isCloneable = exports.isCloneable = function isCloneable(fieldDescriptor) {
  var config = fieldDescriptor[configKey];

  if (config && 'cloneable' in config) {
    return config.cloneable;
  }

  return true;
};

var isAuthority = exports.isAuthority = function isAuthority(recordTypeConfig) {
  return (0, _get2.default)(recordTypeConfig, ['serviceConfig', 'serviceType']) === 'authority';
};

var validateLocation = exports.validateLocation = function validateLocation(config, location) {
  var recordType = location.recordType,
      vocabulary = location.vocabulary,
      csid = location.csid,
      subresource = location.subresource,
      relatedRecordType = location.relatedRecordType,
      relatedCsid = location.relatedCsid;


  var recordTypeConfig = (0, _get2.default)(config, ['recordTypes', recordType]);

  if (!recordTypeConfig) {
    return {
      error: {
        recordType: recordType,
        code: _errorCodes.ERR_UNKNOWN_RECORD_TYPE
      }
    };
  }

  if (isAuthority(recordTypeConfig)) {
    if (!vocabulary) {
      return {
        error: {
          recordType: recordType,
          code: _errorCodes.ERR_MISSING_VOCABULARY
        }
      };
    }

    var vocabularyConfig = (0, _get2.default)(recordTypeConfig, ['vocabularies', vocabulary]);

    if (!vocabularyConfig) {
      return {
        error: {
          recordType: recordType,
          vocabulary: vocabulary,
          code: _errorCodes.ERR_UNKNOWN_VOCABULARY
        }
      };
    }
  } else if (vocabulary) {
    return {
      error: {
        recordType: recordType,
        vocabulary: vocabulary,
        code: _errorCodes.ERR_UNKNOWN_VOCABULARY
      }
    };
  }

  if (csid && !(0, _csidHelpers.isCsid)(csid) && !(0, _csidHelpers.isUrnCsid)(csid)) {
    return {
      error: {
        csid: csid,
        code: _errorCodes.ERR_INVALID_CSID
      }
    };
  }

  if (subresource) {
    var subresourceConfig = (0, _get2.default)(config, ['subresources', subresource]);

    if (!subresourceConfig) {
      return {
        error: {
          subresource: subresource,
          code: _errorCodes.ERR_UNKNOWN_SUBRESOURCE
        }
      };
    }
  }

  if (relatedRecordType) {
    var serviceType = (0, _get2.default)(recordTypeConfig, ['serviceConfig', 'serviceType']);
    var relatedServiceType = (0, _get2.default)(config, ['recordTypes', relatedRecordType, 'serviceConfig', 'serviceType']);

    if (serviceType !== 'procedure' && serviceType !== 'object' || relatedServiceType !== 'procedure' && relatedServiceType !== 'object') {
      return {
        error: {
          recordType: recordType,
          relatedRecordType: relatedRecordType,
          code: _errorCodes.ERR_INVALID_RELATED_TYPE
        }
      };
    }
  }

  if (relatedCsid && !(0, _csidHelpers.isCsid)(relatedCsid)) {
    return {
      error: {
        csid: relatedCsid,
        code: _errorCodes.ERR_INVALID_CSID
      }
    };
  }

  return {};
};

var getDefaultSearchRecordType = exports.getDefaultSearchRecordType = function getDefaultSearchRecordType(config) {
  var recordTypes = config.recordTypes;

  var names = Object.keys(recordTypes);

  var defaultSearchRecordType = void 0;

  for (var i = 0; i < names.length; i += 1) {
    var name = names[i];

    if (recordTypes[name].defaultForSearch) {
      defaultSearchRecordType = name;
      break;
    }
  }

  return defaultSearchRecordType || names[0];
};

var getDefaultSearchVocabulary = exports.getDefaultSearchVocabulary = function getDefaultSearchVocabulary(recordTypeConfig) {
  var vocabularies = recordTypeConfig.vocabularies;

  var names = Object.keys(vocabularies);

  var defaultSearchVocabulary = void 0;

  for (var i = 0; i < names.length; i += 1) {
    var name = names[i];

    if (vocabularies[name].defaultForSearch) {
      defaultSearchVocabulary = name;
      break;
    }
  }

  return defaultSearchVocabulary || names[0];
};

var findField = exports.findField = function findField(parentFieldDescriptor, fieldName) {
  var keys = Object.keys(parentFieldDescriptor);

  for (var i = 0; i < keys.length; i += 1) {
    var key = keys[i];
    var value = parentFieldDescriptor[key];

    if (key === fieldName) {
      return value;
    }

    if (key !== configKey) {
      var fieldDescriptor = findField(value, fieldName);

      if (fieldDescriptor) {
        return fieldDescriptor;
      }
    }
  }

  return null;
};

var findFieldConfigInPart = exports.findFieldConfigInPart = function findFieldConfigInPart(recordTypeConfig, partName, fieldName) {
  var partDescriptor = (0, _get2.default)(recordTypeConfig, ['fields', 'document', _recordDataHelpers.NS_PREFIX + ':' + partName]);

  if (!partDescriptor) {
    return null;
  }

  // 1. Look for the field as a direct child of the part.

  var fieldDescriptor = partDescriptor[fieldName];

  // 2. Check for a memoized result.

  if (!fieldDescriptor) {
    fieldDescriptor = (0, _get2.default)(recordTypeConfig, ['fieldsByPart', partName, fieldName]);
  }

  // 3. Search for a nested field.

  if (typeof fieldDescriptor === 'undefined') {
    fieldDescriptor = findField(partDescriptor, fieldName);

    // Memoize the result.

    (0, _set2.default)(recordTypeConfig, ['fieldsByPart', partName, fieldName], fieldDescriptor);
  }

  return fieldDescriptor ? fieldDescriptor[configKey] : null;
};